@@ -4,7 +4,7 @@
  * Gnome Crystal
  * atomsdlg.cc 
  *
- * Copyright (C) 2002-2003
+ * Copyright (C) 2002-2004
  *
  * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
  *
@@ -101,7 +101,7 @@ static void on_charge_changed(GtkSpinButton *btn, gcAtomsDlg *pBox)
 	pBox->SetCharge(gtk_spin_button_get_value_as_int(btn));
 }
 
-gcAtomsDlg::gcAtomsDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/atoms.glade", "atoms", "atoms_dialog")
+gcAtomsDlg::gcAtomsDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/atoms.glade", "atoms")
 {
 	m_pDoc = pDoc;
 	pDoc->NotifyDialog(this);
@@ -127,40 +127,41 @@ gcAtomsDlg::gcAtomsDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/atoms
 	GtkTreeViewColumn *column;
 	/* column for element */
 	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes("Atom", renderer, "text", 0, NULL);
-	/* set this column to a fixed sizing (of 75 pixels) */
+puts(_("Atom"));
+	column = gtk_tree_view_column_new_with_attributes(_("Atom"), renderer, "text", 0, NULL);
+	/* set this column to a minimum sizing (of 80 pixels) */
 	gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_GROW_ONLY);
-	gtk_tree_view_column_set_min_width(GTK_TREE_VIEW_COLUMN (column), 175);
+	gtk_tree_view_column_set_min_width(GTK_TREE_VIEW_COLUMN (column), 80);
 	gtk_tree_view_append_column(tree, column);
 	/* column for x */
 	renderer = gtk_cell_renderer_text_new ();
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (on_edited), this);
 	g_object_set(G_OBJECT(renderer), "editable", true, NULL);
 	g_object_set_data(G_OBJECT (renderer), "column", (gint *)COLUMN_X);
-	column = gtk_tree_view_column_new_with_attributes("x", renderer, "text", 1, NULL);
-	/* set this column to a fixed sizing (of 50 pixels) */
+	column = gtk_tree_view_column_new_with_attributes(_("x"), renderer, "text", 1, NULL);
+	/* set this column to a fixed sizing (of 70 pixels) */
 	gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
-	gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN (column), 50);
+	gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN (column), 70);
 	gtk_tree_view_append_column(tree, column);
 	/* column for y */
 	renderer = gtk_cell_renderer_text_new ();
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (on_edited), this);
 	g_object_set(G_OBJECT(renderer), "editable", true, NULL);
 	g_object_set_data(G_OBJECT (renderer), "column", (gint *)COLUMN_Y);
-	column = gtk_tree_view_column_new_with_attributes("y", renderer, "text", 2, NULL);
-	/* set this column to a fixed sizing (of 50 pixels) */
+	column = gtk_tree_view_column_new_with_attributes(_("y"), renderer, "text", 2, NULL);
+	/* set this column to a fixed sizing (of 70 pixels) */
 	gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
-	gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN (column), 50);
+	gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN (column), 70);
 	gtk_tree_view_append_column(tree, column);
 	/* column for z */
 	renderer = gtk_cell_renderer_text_new ();
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (on_edited), this);
 	g_object_set(G_OBJECT(renderer), "editable", true, NULL);
 	g_object_set_data(G_OBJECT (renderer), "column", (gint *)COLUMN_Z);
-	column = gtk_tree_view_column_new_with_attributes("z", renderer, "text", 3, NULL);
-	/* set this column to a fixed sizing (of 50 pixels) */
+	column = gtk_tree_view_column_new_with_attributes(_("z"), renderer, "text", 3, NULL);
+	/* set this column to a fixed sizing (of 70 pixels) */
 	gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
-	gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN (column), 50);
+	gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN (column), 70);
 	gtk_tree_view_append_column(tree, column);
 	m_nElt = 0;
 	m_AtomSelected = -1;
@@ -189,7 +190,7 @@ gcAtomsDlg::gcAtomsDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/atoms
 				  -1);
 	}
 	if (!m_Atoms->len)gtk_widget_set_sensitive(DeleteAllBtn, false);
-	AtomColor = (GnomeColorPicker*) glade_xml_get_widget(xml, "atomcolor");
+	AtomColor = (GnomeColorPicker*) glade_xml_get_widget(xml, "color");
 	gtk_widget_set_sensitive(GTK_WIDGET(AtomColor), false);
 	CustomColor = (GtkToggleButton*) glade_xml_get_widget(xml, "custom_color");
 	g_signal_connect (G_OBJECT (CustomColor), "toggled", G_CALLBACK (on_toggled_color), this);
